RoundingIncrement

Enum RoundingIncrement 

#[non_exhaustive]
pub enum RoundingIncrement { MultiplesOf1, MultiplesOf2, MultiplesOf5, MultiplesOf25, }
Increment used in a rounding operation.

Forces a rounding operation to round to only multiples of the specified increment.

Example

use fixed_decimal::{Decimal, RoundingIncrement, SignedRoundingMode, UnsignedRoundingMode};
use writeable::assert_writeable_eq;
let dec = Decimal::from_str("-7.266").unwrap();
let mode = SignedRoundingMode::Unsigned(UnsignedRoundingMode::Expand);
let increments = [
    // .266 normally expands to .27 when rounding on position -2...
    (RoundingIncrement::MultiplesOf1, "-7.27"),
    // ...however, when rounding to multiples of 2, .266 expands to .28, since the next multiple
    // of 2 bigger than the least significant digit of the rounded value (7) is 8.
    (RoundingIncrement::MultiplesOf2, "-7.28"),
    // .266 expands to .30, since the next multiple of 5 bigger than 7 is 10.
    (RoundingIncrement::MultiplesOf5, "-7.30"),
    // .266 expands to .50, since the next multiple of 25 bigger than 27 is 50.
    // Note how we compare against 27 instead of only 7, because the increment applies to
    // the two least significant digits of the rounded value instead of only the least
    // significant digit.
    (RoundingIncrement::MultiplesOf25, "-7.50"),
];

for (increment, expected) in increments {
    assert_writeable_eq!(
        dec.clone().rounded_with_mode_and_increment(
            -2,
            mode,
            increment
        ),
        expected
    );
}

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


MultiplesOf1

Round the least significant digit to any digit (0-9).

This is the default rounding increment for all the methods that don’t take a RoundingIncrement as an argument.



MultiplesOf2

Round the least significant digit to multiples of two (0, 2, 4, 6, 8).



MultiplesOf5

Round the least significant digit to multiples of five (0, 5).



MultiplesOf25

Round the two least significant digits to multiples of twenty-five (0, 25, 50, 75).

With this increment, the rounding position index will match the least significant digit of the multiple of 25; e.g. the number .264 expanded at position -2 using increments of 25 will give .50 as a result, since the next multiple of 25 bigger than 26 is 50.