SignDisplay

Enum SignDisplay 

#[non_exhaustive]
pub enum SignDisplay { Auto, Never, Always, ExceptZero, Negative, }
Configuration for when to render the minus sign or plus sign.

The primary definition of this type is in the fixed_decimal crate. Other ICU4X crates re-export it for convenience.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Auto

Render the sign according to locale preferences. In most cases, this means a minus sign will be shown on negative numbers, and no sign will be shown on positive numbers.



Never

Do not display the sign. Positive and negative numbers are indistinguishable.



Always

Show a minus sign on negative numbers and a plus sign on positive numbers, including zero.



ExceptZero

Show a minus sign on negative numbers and a plus sign on positive numbers, except do not show any sign on positive or negative zero.



Negative

Show a minus sign on strictly negative numbers. Do not show a sign on positive numbers or on positive or negative zero.

This differs from Auto in that it does not render a sign on negative zero.