CompactDecimal

Struct CompactDecimal 

pub struct CompactDecimal { /* private fields */ }
A struct containing a Decimal significand together with an exponent, representing a number written in compact notation (such as 1.2M). This represents a source number, as defined in UTS #35. The value exponent=0 represents a number in non-compact notation (such as 1 200 000).

This is distinct from crate::ScientificDecimal because it does not represent leading 0s nor a sign in the exponent, and behaves differently in pluralization.

Implementations

Source

impl CompactDecimal

pub fn from_significand_and_exponent(significand: Decimal, exponent: u8) -> Self

Constructs a CompactDecimal from its significand and exponent.

pub fn significand(&self) -> &Decimal

Returns a reference to the significand of self.

assert_eq!(
    CompactDecimal::from_str("+1.20c6").unwrap().significand(),
    &Decimal::from_str("+1.20").unwrap()
);
pub fn into_significand(self) -> Decimal

Returns the significand of self.

assert_eq!(
    CompactDecimal::from_str("+1.20c6")
        .unwrap()
        .into_significand(),
    Decimal::from_str("+1.20").unwrap()
);
pub fn exponent(&self) -> u8

Returns the exponent of self.

assert_eq!(CompactDecimal::from_str("+1.20c6").unwrap().exponent(), 6);
assert_eq!(CompactDecimal::from_str("1729").unwrap().exponent(), 0);
Source

impl CompactDecimal

pub fn to_string(&self) -> String

Converts the given value to a String.

Under the hood, this uses an efficient [Writeable] implementation. However, in order to avoid allocating a string, it is more efficient to use [Writeable] directly.

Source

impl CompactDecimal

pub fn try_from_str(s: &str) -> Result<Self, ParseError>

Parses a CompactDecimal.